==> haskell-foldl-1.4.7-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.7
visibility:           public
id:                   foldl-1.4.7-BvmcmPHpOIZ7r36J9WgYFh
key:                  foldl-1.4.7-BvmcmPHpOIZ7r36J9WgYFh
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  911a0db8b93e65a475694ca9fe602c14
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl

hidden-modules:       Control.Foldl.Optics Control.Foldl.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/foldl-1.4.7
library-dirs:         /usr/lib/ghc-8.10.1/site-local/foldl-1.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/foldl-1.4.7
hs-libraries:         HSfoldl-1.4.7-BvmcmPHpOIZ7r36J9WgYFh
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    comonad-5.0.6-KcKrHKRkGOZ50Yzo9mZZYb containers-0.6.2.1
    contravariant-1.5.2-3rEsfj3YINxBWDceLgF1Rb
    hashable-1.3.0.0-9VsPqbCnhR5IR1hPcVPQ9S
    mwc-random-0.14.0.0-AEOH8HF2v8W2ANQoQk1Dgc
    primitive-0.7.1.0-Cabm7bcbTFaJrdRYs3QMp6
    profunctors-5.5.2-1Mme99yAMex22ygpLy5f18
    semigroupoids-5.3.4-61whxVGstcAC8wEplV75j2 text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.11.0-4xXgRDqRkAy1dBzEEXx9oz
    vector-0.12.1.2-H0z3zqOucdK6qK7YVRJGW2
    vector-builder-0.3.8-3sjUNi082lnJOzswrttsAf

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.8-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 foldl
version:              1.4.8
visibility:           public
id:                   foldl-1.4.8-8GAxyNUoA9P4V4scAWJXgV
key:                  foldl-1.4.8-8GAxyNUoA9P4V4scAWJXgV
license:              BSD-3-Clause
copyright:            2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  90b6759d07c5036e74042a0bee0fcb44
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl

hidden-modules:       Control.Foldl.Optics Control.Foldl.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/foldl-1.4.8
library-dirs:         /usr/lib/ghc-8.10.1/site-local/foldl-1.4.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/foldl-1.4.8
hs-libraries:         HSfoldl-1.4.8-8GAxyNUoA9P4V4scAWJXgV
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    comonad-5.0.6-17SBQDgSamQ5jGIWZXPoVU containers-0.6.2.1
    contravariant-1.5.2-3rEsfj3YINxBWDceLgF1Rb
    hashable-1.3.0.0-DiGbvYLsPmxJgdfVCor8qD
    mwc-random-0.14.0.0-AFatXMdU4oOGa5IApjRBXs
    primitive-0.7.1.0-Fy9GtLXiUTxJSxYCQpQePZ
    profunctors-5.5.2-BdAKwEGCSAJG16fq3cbzXo
    semigroupoids-5.3.4-25WPaQzvVY4CrcKXepAyco text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.12.0-7yiTvjz2UcTGgWhTtgXiX9
    vector-0.12.1.2-8A0MDgLPPVcWTXsA8tpNg
    vector-builder-0.3.8-6rPNNHp75jDKvqy3BVrJbi

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
